@@ -1,56 +1,4 @@
 
- # /*---------------------------------------------------------------------------------------------------*/
-
-SV *
-dvb_device()
-	INIT:
-  AV * results;
-
-	struct devinfo *entry ;
-	struct list_head *info ;
-	struct list_head *item, *safe;
-
-  results = (AV *)sv_2mortal((SV *)newAV());
-
-	CODE:
-
-  /* get info */
-  info = dvb_probe(0) ;
-
-  /* TODO: return the device names too */
-
-  /* Create Perl data */
-  list_for_each(item, info)
-  {
-  HV * rh;
-  HV * ch;
-  int flags ;
-
-		entry = list_entry(item, struct devinfo, next);
-
-		/* Convert structure fields into hash elements */
-		rh = device_info_hv(entry) ;
-
-		av_push(results, newRV((SV *)rh));
-
-  }
-
-
-	/* Free up results */
-  /* TODO: Provide C call to do this */
-  list_for_each_safe(item,safe,info)
-  {
-		entry = list_entry(item, struct devinfo, next);
-		list_del(&entry->next);
-		free(entry);
-  };
-
-
-  RETVAL = newRV((SV *)results);
-	OUTPUT:
-  RETVAL
-
-
 
 # /*---------------------------------------------------------------------------------------------------*/
 
